 #-----------------------------------------------
#                        
#  Keith McMillen Instruments 2014       
#                        
#  Authors:                   
#   Evan Bogunia <evanbeta@keithmcmillen.com>
#                        
#-----------------------------------------------

from __future__ import with_statement

import Live #Now the Live API is available
import time #Now we can use time functions for time-stamping our log file outputs

from _Framework.ButtonElement import ButtonElement
from _Framework.CompoundComponent import CompoundComponent
from _Framework.ControlElement import ControlElement
from _Framework.ControlSurface import ControlSurface
from _Framework.ControlSurfaceComponent import ControlSurfaceComponent
from _Framework.InputControlElement import *
from _Framework.ButtonMatrixElement import ButtonMatrixElement

#define global variables
CHANNEL = 0  #channels are numbered 0 - 15
is_momentary = True

class QuNexusLights(ControlSurface):
  __module__ = __name__
  __doc__ = "QuNexus Keyboard controller script"
  
  def __init__(self, c_instance):
    ControlSurface.__init__(self, c_instance)
    with self.component_guard():
      matrix = ButtonMatrixElement()
      matrix.name = 'Button_Matrix'
      for row in range(25):
        button_row = []
        button = ButtonElement(is_momentary,MIDI_NOTE_TYPE,CHANNEL,48 + row)
        button.name = ('button_' + str(row))
        button_row.append(button)
        matrix.add_row(button_row)

  def disconnect(self):
    #clean things up on disconnect
    
    #create entry in log file
    self.log_message(time.strftime("%d.%m.%Y %H:%M:%S", time.localtime()) + "----------QuNexus Basic log closed----------")
    
    ControlSurface.disconnect(self)
    return None
